# pydygp

A *Py*thon library for carrying out statistical inference in *dy*namic systems driven by latent *G*aussian *p*rocesses.

- **Website and documentation:** https://pydygp.readthedocs.io/en/latest/
